@@ -1,16 +1,13 @@
 use strict; #-*-cperl-*-
 use warnings;
 
-use lib qw( ../../.. );
-
 =head1 NAME
 
-Algorithm::Evolutionary::Op::Replace_Worst - Incorporate individuals into the population replacing the worst ones
+Algorithm::Evolutionary::Op::Replace_Worst - Incorporate an individual into the population replacing the worst one
 
 =head1 SYNOPSIS
 
-  my $op = new Algorithm::Evolutionary::Op::Replace_Worst; 
-  $op->apply( $old_population_hashref, $new_population_hashref );
+  my $op = new Algorithm::Evolutionary::Op::Novelty_Mutation $ref_to_population_hash; #The population hash can be obtained from some fitness functions
 
 =head1 Base Class
 
@@ -28,7 +25,7 @@ hash, and discarded if they are already in the population.
 
 package Algorithm::Evolutionary::Op::Replace_Worst;
 
-our ($VERSION) = ( '$Revision: 3.2 $ ' =~ /(\d+\.\d+)/ );
+our ($VERSION) = ( '$Revision: 2.1 $ ' =~ /(\d+\.\d+)/ );
 
 use Carp;
 
@@ -62,10 +59,10 @@ sub apply ($;$){
   my $chromosome_list = shift || croak "No new population here!";
   
   #Sort
-  my @sorted_population = sort { $b->Fitness() <=> $a->Fitness(); }
+  my @sorted_population = sort { $b->{_fitness} <=> $a->{_fitness}; }
     @$population ;
   my $to_eliminate = scalar @$chromosome_list;
-  splice ( @sorted_population, -$to_eliminate );
+  splice ( @sorted_population, - $to_eliminate, $to_eliminate );
   push @sorted_population, @$chromosome_list;
 
   return \@sorted_population;
@@ -73,23 +70,15 @@ sub apply ($;$){
 
 }
 
-=head1 SEE ALSO
-
-L<Algorithm::Evolutionary::Op::Generation_Skeleton>, where the
-replacement policy is one of the parameters 
-
-It can also be used in L<POE::Component::Algorithm::Evolutionary> for
-insertion of new individuals asynchronously.
-
 =head1 Copyright
   
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2010/12/20 16:56:46 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Replace_Worst.pm,v 3.2 2010/12/20 16:56:46 jmerelo Exp $ 
+  CVS Info: $Date: 2009/02/09 10:05:06 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Replace_Worst.pm,v 2.1 2009/02/09 10:05:06 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.2 $
+  $Revision: 2.1 $
   $Name $
 
 =cut
