@@ -12,9 +12,9 @@ or
 
   prompt% perl tide_float.pl <population> <number of generations>
 
-will show the values of the two floating-point components of the
-chromosome and finally the best value and fitness reached, which
-should be as close to 1 as possible.
+  Shows the values of the two floating-point components of the
+  chromosome and finally the best value and fitness reached, which
+  should be as close to 1 as possible.
   
 
 =head1 DESCRIPTION  
@@ -39,7 +39,6 @@ use Algorithm::Evolutionary qw( Individual::Vector Op::Easy
 #----------------------------------------------------------#
 my $popSize = shift || 100; #Population size
 my $numGens = shift || 100; #Max number of generations
-my $dimension = shift || 2; #Vector dimension
 
 #----------------------------------------------------------#
 #Fitness function will be Tide
@@ -57,14 +56,16 @@ my $funcionMarea = sub {
 my @pop;
 #Creamos $popSize individuos
 for ( 0..$popSize ) {
-  my $indi = Algorithm::Evolutionary::Individual::Vector->new( $dimension );
+  my $indi = Algorithm::Evolutionary::Individual::Vector->new( 2 );
   push( @pop, $indi );
 }
 
+
 #----------------------------------------------------------#
 # Variation operators
 my $m = Algorithm::Evolutionary::Op::GaussianMutation->new( 0, 0.1 );
-my $c = Algorithm::Evolutionary::Op::VectorCrossover->new( $dimension );
+my $c = Algorithm::Evolutionary::Op::VectorCrossover->new(2);
+
 
 #----------------------------------------------------------#
 #Usamos estos operadores para definir una generación del algoritmo. Lo cual
@@ -91,12 +92,12 @@ do {
   print "$contador : ", $pop[0]->asString(), "\n" ;
 
   $contador++;
-} while( ( $contador < $numGens ) && ( $pop[0]->Fitness() < 1 ) );
+} while( $contador < $numGens );
 
 
 #----------------------------------------------------------#
 #leemos el mejor resultado
-my ( $x, $y ) = @{$pop[0]->{'_array'}};
+my ( $x, $y ) = @{$pop[0]->{_array}};
 
 #Mostramos los resultados obtenidos
 print "El mejor es:\n\t ",$pop[0]->asString(),"\n\t x=$x \n\t y=$y \n\t Fitness: ",$pop[0]->Fitness(),"\n";
@@ -114,10 +115,10 @@ Contributed by Pedro Castillo Valdivieso, modified by J. J. Merelo
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2012/12/08 10:12:37 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/scripts/tide_float.pl,v 3.1 2012/12/08 10:12:37 jmerelo Exp $ 
+  CVS Info: $Date: 2009/02/08 18:46:18 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/scripts/tide_float.pl,v 1.1 2009/02/08 18:46:18 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.1 $
+  $Revision: 1.1 $
   $Name $
 
 =cut
